@@ -81,6 +81,7 @@ class ClippedPPOLoss(Module):
      $$d^\pi(s) = (1 - \gamma) \sum_{t=0}^\infty \gamma^t P(s_t = s | \pi)$$
 
     Then,
+
     \begin{align}
     J(\pi_\theta) - J(\pi_{\theta_{OLD}})
     &= \mathbb{E}_{\tau \sim \pi_\theta} \Biggl[
@@ -124,7 +125,7 @@ class ClippedPPOLoss(Module):
      \Biggr]
     \\
     &\approx \frac{1}{1 - \gamma}
-     \mathop{\mathbb{E}}_{\color{orange}{s \sim d^{\pi_{\theta_{OLD}}}}
+     \mathop{\mathbb{E}}_{\textcolor{orange}{s \sim d^{\pi_{\theta_{OLD}}}}
      \atop a \sim \pi_{\theta_{OLD}}} \Biggl[
       \frac{\pi_\theta(a|s)}{\pi_{\theta_{OLD}}(a|s)} A^{\pi_{OLD}}(s, a)
      \Biggr]
