@@ -23,7 +23,7 @@ def knn(queries: torch.Tensor, index: faiss.IndexFlatL2, keys_store: np.ndarray,
     """
     ## $k$-NN to get $p(w_t, c_t)$
 
-    Here we refer to $f(\color{yellowgreen}{c_t})$ as queries,
+    Here we refer to $f(\textcolor{yellowgreen}{c_t})$ as queries,
     $f(c_i)$ as keys and $w_i$ as values.
     """
 
@@ -33,7 +33,7 @@ def knn(queries: torch.Tensor, index: faiss.IndexFlatL2, keys_store: np.ndarray,
     # Flatten the `batch` and `sequence` dimensions of queries
     queries = queries.view(-1, queries_shape[-1])
 
-    # Find 10 nearest neighbors of $f(\color{yellowgreen}{c_t})$ among $f(c_i)$.
+    # Find 10 nearest neighbors of $f(\textcolor{yellowgreen}{c_t})$ among $f(c_i)$.
     # `distance` is the distance given by FAISS and `idx`, $i$ is the index of it in `keys_store`.
     distance, idx = index.search(queries.numpy(), 10)
 
@@ -46,7 +46,7 @@ def knn(queries: torch.Tensor, index: faiss.IndexFlatL2, keys_store: np.ndarray,
 
     # Normalize $f(c_i)$
     keys_found_n = keys_found / torch.sqrt((keys_found ** 2).sum(-1, keepdims=True) + 1e-10)
-    # Normalize $f($\color{yellowgreen}{c_t})$
+    # Normalize $f(\textcolor{yellowgreen}{c_t})$
     queries_n = queries / torch.sqrt((queries ** 2).sum(-1, keepdims=True) + 1e-10)
 
     # Get the dot-product, or cosine similarity
